@@ -31,7 +31,7 @@ Creates a new Chart::Clicker::Decoration
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 SEE ALSO
 
